package com.ruoyi.rc.service;

import java.util.List;
import com.ruoyi.rc.domain.TChapterTemplate;

/**
 * 章节模板Service接口
 * 
 * @author ruoyi
 * @date 2024-07-31
 */
public interface ITChapterTemplateService 
{
    public String selectNameByCode(String code);

    /**
     * 查询章节模板
     * 
     * @param id 章节模板主键
     * @return 章节模板
     */
    public TChapterTemplate selectTChapterTemplateById(Long id);

    /**
     * 查询章节模板列表
     * 
     * @param tChapterTemplate 章节模板
     * @return 章节模板集合
     */
    public List<TChapterTemplate> selectTChapterTemplateList(TChapterTemplate tChapterTemplate);

    /**
     * 新增章节模板
     * 
     * @param tChapterTemplate 章节模板
     * @return 结果
     */
    public int insertTChapterTemplate(TChapterTemplate tChapterTemplate);

    /**
     * 修改章节模板
     * 
     * @param tChapterTemplate 章节模板
     * @return 结果
     */
    public int updateTChapterTemplate(TChapterTemplate tChapterTemplate);

    /**
     * 批量删除章节模板
     * 
     * @param ids 需要删除的章节模板主键集合
     * @return 结果
     */
    public int deleteTChapterTemplateByIds(Long[] ids);

    /**
     * 删除章节模板信息
     * 
     * @param id 章节模板主键
     * @return 结果
     */
    public int deleteTChapterTemplateById(Long id);
}
